import sys
import ctypes
from Phidget22.PhidgetSupport import PhidgetSupport
from Phidget22.Async import *
from Phidget22.PhidgetException import PhidgetException

from Phidget22.Phidget import Phidget

class HumiditySensor(Phidget):

	def __init__(self):
		Phidget.__init__(self)
		self.handle = ctypes.c_void_p()

		if sys.platform == 'win32':
			self._HumidityChangeFactory = ctypes.WINFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.c_double)
		else:
			self._HumidityChangeFactory = ctypes.CFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.c_double)
		self._HumidityChange = None
		self._onHumidityChange = None

		__func = PhidgetSupport.getDll().PhidgetHumiditySensor_create
		__func.restype = ctypes.c_int32
		res = __func(ctypes.byref(self.handle))

		if res > 0:
			raise PhidgetException(res)

	def __del__(self):
		Phidget.__del__(self)

	def _localHumidityChangeEvent(self, handle, userPtr, humidity):
		if self._HumidityChange == None:
			return
		self._HumidityChange(self, humidity)

	def setOnHumidityChangeHandler(self, handler):
		if handler == None:
			self._HumidityChange = None
			self._onHumidityChange = None
		else:
			self._HumidityChange = handler
			self._onHumidityChange = self._HumidityChangeFactory(self._localHumidityChangeEvent)

		try:
			__func = PhidgetSupport.getDll().PhidgetHumiditySensor_setOnHumidityChangeHandler
			__func.restype = ctypes.c_int32
			res = __func(self.handle, self._onHumidityChange, None)
		except RuntimeError:
			self._HumidityChange = None
			self._onHumidityChange = None

	def getDataInterval(self):
		_DataInterval = ctypes.c_uint32()

		__func = PhidgetSupport.getDll().PhidgetHumiditySensor_getDataInterval
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_DataInterval))

		if result > 0:
			raise PhidgetException(result)

		return _DataInterval.value

	def setDataInterval(self, DataInterval):
		_DataInterval = ctypes.c_uint32(DataInterval)

		__func = PhidgetSupport.getDll().PhidgetHumiditySensor_setDataInterval
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _DataInterval)

		if result > 0:
			raise PhidgetException(result)


	def getMinDataInterval(self):
		_MinDataInterval = ctypes.c_uint32()

		__func = PhidgetSupport.getDll().PhidgetHumiditySensor_getMinDataInterval
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinDataInterval))

		if result > 0:
			raise PhidgetException(result)

		return _MinDataInterval.value

	def getMaxDataInterval(self):
		_MaxDataInterval = ctypes.c_uint32()

		__func = PhidgetSupport.getDll().PhidgetHumiditySensor_getMaxDataInterval
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxDataInterval))

		if result > 0:
			raise PhidgetException(result)

		return _MaxDataInterval.value

	def getDataRate(self):
		_DataRate = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetHumiditySensor_getDataRate
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_DataRate))

		if result > 0:
			raise PhidgetException(result)

		return _DataRate.value

	def setDataRate(self, DataRate):
		_DataRate = ctypes.c_double(DataRate)

		__func = PhidgetSupport.getDll().PhidgetHumiditySensor_setDataRate
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _DataRate)

		if result > 0:
			raise PhidgetException(result)


	def getMinDataRate(self):
		_MinDataRate = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetHumiditySensor_getMinDataRate
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinDataRate))

		if result > 0:
			raise PhidgetException(result)

		return _MinDataRate.value

	def getMaxDataRate(self):
		_MaxDataRate = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetHumiditySensor_getMaxDataRate
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxDataRate))

		if result > 0:
			raise PhidgetException(result)

		return _MaxDataRate.value

	def getHumidity(self):
		_Humidity = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetHumiditySensor_getHumidity
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_Humidity))

		if result > 0:
			raise PhidgetException(result)

		return _Humidity.value

	def getMinHumidity(self):
		_MinHumidity = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetHumiditySensor_getMinHumidity
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinHumidity))

		if result > 0:
			raise PhidgetException(result)

		return _MinHumidity.value

	def getMaxHumidity(self):
		_MaxHumidity = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetHumiditySensor_getMaxHumidity
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxHumidity))

		if result > 0:
			raise PhidgetException(result)

		return _MaxHumidity.value

	def getHumidityChangeTrigger(self):
		_HumidityChangeTrigger = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetHumiditySensor_getHumidityChangeTrigger
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_HumidityChangeTrigger))

		if result > 0:
			raise PhidgetException(result)

		return _HumidityChangeTrigger.value

	def setHumidityChangeTrigger(self, HumidityChangeTrigger):
		_HumidityChangeTrigger = ctypes.c_double(HumidityChangeTrigger)

		__func = PhidgetSupport.getDll().PhidgetHumiditySensor_setHumidityChangeTrigger
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _HumidityChangeTrigger)

		if result > 0:
			raise PhidgetException(result)


	def getMinHumidityChangeTrigger(self):
		_MinHumidityChangeTrigger = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetHumiditySensor_getMinHumidityChangeTrigger
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinHumidityChangeTrigger))

		if result > 0:
			raise PhidgetException(result)

		return _MinHumidityChangeTrigger.value

	def getMaxHumidityChangeTrigger(self):
		_MaxHumidityChangeTrigger = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetHumiditySensor_getMaxHumidityChangeTrigger
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxHumidityChangeTrigger))

		if result > 0:
			raise PhidgetException(result)

		return _MaxHumidityChangeTrigger.value



import sys
import ctypes
class MotorPositionType:
	# Configures the controller to use the encoder as a position source
	MOTOR_POSITION_TYPE_ENCODER = 1
	# Configures the controller to use the hall-effect sensor as a position source
	MOTOR_POSITION_TYPE_HALL = 2

	@classmethod
	def getName(self, val):
		if val == self.MOTOR_POSITION_TYPE_ENCODER:
			return "MOTOR_POSITION_TYPE_ENCODER"
		if val == self.MOTOR_POSITION_TYPE_HALL:
			return "MOTOR_POSITION_TYPE_HALL"
		return "<invalid enumeration value>"



import sys
import ctypes
from Phidget22.PhidgetSupport import PhidgetSupport
from Phidget22.Async import *
from Phidget22.FanMode import FanMode
from Phidget22.PhidgetException import PhidgetException

from Phidget22.Phidget import Phidget

class DCMotor(Phidget):

	def __init__(self):
		Phidget.__init__(self)
		self.handle = ctypes.c_void_p()
		self._setTargetVelocity_async = None
		self._onsetTargetVelocity_async = None

		if sys.platform == 'win32':
			self._BackEMFChangeFactory = ctypes.WINFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.c_double)
		else:
			self._BackEMFChangeFactory = ctypes.CFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.c_double)
		self._BackEMFChange = None
		self._onBackEMFChange = None

		if sys.platform == 'win32':
			self._BrakingStrengthChangeFactory = ctypes.WINFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.c_double)
		else:
			self._BrakingStrengthChangeFactory = ctypes.CFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.c_double)
		self._BrakingStrengthChange = None
		self._onBrakingStrengthChange = None

		if sys.platform == 'win32':
			self._VelocityUpdateFactory = ctypes.WINFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.c_double)
		else:
			self._VelocityUpdateFactory = ctypes.CFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.c_double)
		self._VelocityUpdate = None
		self._onVelocityUpdate = None

		__func = PhidgetSupport.getDll().PhidgetDCMotor_create
		__func.restype = ctypes.c_int32
		res = __func(ctypes.byref(self.handle))

		if res > 0:
			raise PhidgetException(res)

	def __del__(self):
		Phidget.__del__(self)

	def _localBackEMFChangeEvent(self, handle, userPtr, backEMF):
		if self._BackEMFChange == None:
			return
		self._BackEMFChange(self, backEMF)

	def setOnBackEMFChangeHandler(self, handler):
		if handler == None:
			self._BackEMFChange = None
			self._onBackEMFChange = None
		else:
			self._BackEMFChange = handler
			self._onBackEMFChange = self._BackEMFChangeFactory(self._localBackEMFChangeEvent)

		try:
			__func = PhidgetSupport.getDll().PhidgetDCMotor_setOnBackEMFChangeHandler
			__func.restype = ctypes.c_int32
			res = __func(self.handle, self._onBackEMFChange, None)
		except RuntimeError:
			self._BackEMFChange = None
			self._onBackEMFChange = None

	def _localBrakingStrengthChangeEvent(self, handle, userPtr, brakingStrength):
		if self._BrakingStrengthChange == None:
			return
		self._BrakingStrengthChange(self, brakingStrength)

	def setOnBrakingStrengthChangeHandler(self, handler):
		if handler == None:
			self._BrakingStrengthChange = None
			self._onBrakingStrengthChange = None
		else:
			self._BrakingStrengthChange = handler
			self._onBrakingStrengthChange = self._BrakingStrengthChangeFactory(self._localBrakingStrengthChangeEvent)

		try:
			__func = PhidgetSupport.getDll().PhidgetDCMotor_setOnBrakingStrengthChangeHandler
			__func.restype = ctypes.c_int32
			res = __func(self.handle, self._onBrakingStrengthChange, None)
		except RuntimeError:
			self._BrakingStrengthChange = None
			self._onBrakingStrengthChange = None

	def _localVelocityUpdateEvent(self, handle, userPtr, velocity):
		if self._VelocityUpdate == None:
			return
		self._VelocityUpdate(self, velocity)

	def setOnVelocityUpdateHandler(self, handler):
		if handler == None:
			self._VelocityUpdate = None
			self._onVelocityUpdate = None
		else:
			self._VelocityUpdate = handler
			self._onVelocityUpdate = self._VelocityUpdateFactory(self._localVelocityUpdateEvent)

		try:
			__func = PhidgetSupport.getDll().PhidgetDCMotor_setOnVelocityUpdateHandler
			__func.restype = ctypes.c_int32
			res = __func(self.handle, self._onVelocityUpdate, None)
		except RuntimeError:
			self._VelocityUpdate = None
			self._onVelocityUpdate = None

	def getAcceleration(self):
		_Acceleration = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetDCMotor_getAcceleration
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_Acceleration))

		if result > 0:
			raise PhidgetException(result)

		return _Acceleration.value

	def setAcceleration(self, Acceleration):
		_Acceleration = ctypes.c_double(Acceleration)

		__func = PhidgetSupport.getDll().PhidgetDCMotor_setAcceleration
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _Acceleration)

		if result > 0:
			raise PhidgetException(result)


	def getMinAcceleration(self):
		_MinAcceleration = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetDCMotor_getMinAcceleration
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinAcceleration))

		if result > 0:
			raise PhidgetException(result)

		return _MinAcceleration.value

	def getMaxAcceleration(self):
		_MaxAcceleration = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetDCMotor_getMaxAcceleration
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxAcceleration))

		if result > 0:
			raise PhidgetException(result)

		return _MaxAcceleration.value

	def getBackEMF(self):
		_BackEMF = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetDCMotor_getBackEMF
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_BackEMF))

		if result > 0:
			raise PhidgetException(result)

		return _BackEMF.value

	def getBackEMFSensingState(self):
		_BackEMFSensingState = ctypes.c_int()

		__func = PhidgetSupport.getDll().PhidgetDCMotor_getBackEMFSensingState
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_BackEMFSensingState))

		if result > 0:
			raise PhidgetException(result)

		return bool(_BackEMFSensingState.value)

	def setBackEMFSensingState(self, BackEMFSensingState):
		_BackEMFSensingState = ctypes.c_int(BackEMFSensingState)

		__func = PhidgetSupport.getDll().PhidgetDCMotor_setBackEMFSensingState
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _BackEMFSensingState)

		if result > 0:
			raise PhidgetException(result)


	def getBrakingStrength(self):
		_BrakingStrength = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetDCMotor_getBrakingStrength
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_BrakingStrength))

		if result > 0:
			raise PhidgetException(result)

		return _BrakingStrength.value

	def getMinBrakingStrength(self):
		_MinBrakingStrength = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetDCMotor_getMinBrakingStrength
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinBrakingStrength))

		if result > 0:
			raise PhidgetException(result)

		return _MinBrakingStrength.value

	def getMaxBrakingStrength(self):
		_MaxBrakingStrength = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetDCMotor_getMaxBrakingStrength
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxBrakingStrength))

		if result > 0:
			raise PhidgetException(result)

		return _MaxBrakingStrength.value

	def getCurrentLimit(self):
		_CurrentLimit = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetDCMotor_getCurrentLimit
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_CurrentLimit))

		if result > 0:
			raise PhidgetException(result)

		return _CurrentLimit.value

	def setCurrentLimit(self, CurrentLimit):
		_CurrentLimit = ctypes.c_double(CurrentLimit)

		__func = PhidgetSupport.getDll().PhidgetDCMotor_setCurrentLimit
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _CurrentLimit)

		if result > 0:
			raise PhidgetException(result)


	def getMinCurrentLimit(self):
		_MinCurrentLimit = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetDCMotor_getMinCurrentLimit
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinCurrentLimit))

		if result > 0:
			raise PhidgetException(result)

		return _MinCurrentLimit.value

	def getMaxCurrentLimit(self):
		_MaxCurrentLimit = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetDCMotor_getMaxCurrentLimit
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxCurrentLimit))

		if result > 0:
			raise PhidgetException(result)

		return _MaxCurrentLimit.value

	def getCurrentRegulatorGain(self):
		_CurrentRegulatorGain = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetDCMotor_getCurrentRegulatorGain
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_CurrentRegulatorGain))

		if result > 0:
			raise PhidgetException(result)

		return _CurrentRegulatorGain.value

	def setCurrentRegulatorGain(self, CurrentRegulatorGain):
		_CurrentRegulatorGain = ctypes.c_double(CurrentRegulatorGain)

		__func = PhidgetSupport.getDll().PhidgetDCMotor_setCurrentRegulatorGain
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _CurrentRegulatorGain)

		if result > 0:
			raise PhidgetException(result)


	def getMinCurrentRegulatorGain(self):
		_MinCurrentRegulatorGain = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetDCMotor_getMinCurrentRegulatorGain
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinCurrentRegulatorGain))

		if result > 0:
			raise PhidgetException(result)

		return _MinCurrentRegulatorGain.value

	def getMaxCurrentRegulatorGain(self):
		_MaxCurrentRegulatorGain = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetDCMotor_getMaxCurrentRegulatorGain
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxCurrentRegulatorGain))

		if result > 0:
			raise PhidgetException(result)

		return _MaxCurrentRegulatorGain.value

	def getDataInterval(self):
		_DataInterval = ctypes.c_uint32()

		__func = PhidgetSupport.getDll().PhidgetDCMotor_getDataInterval
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_DataInterval))

		if result > 0:
			raise PhidgetException(result)

		return _DataInterval.value

	def setDataInterval(self, DataInterval):
		_DataInterval = ctypes.c_uint32(DataInterval)

		__func = PhidgetSupport.getDll().PhidgetDCMotor_setDataInterval
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _DataInterval)

		if result > 0:
			raise PhidgetException(result)


	def getMinDataInterval(self):
		_MinDataInterval = ctypes.c_uint32()

		__func = PhidgetSupport.getDll().PhidgetDCMotor_getMinDataInterval
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinDataInterval))

		if result > 0:
			raise PhidgetException(result)

		return _MinDataInterval.value

	def getMaxDataInterval(self):
		_MaxDataInterval = ctypes.c_uint32()

		__func = PhidgetSupport.getDll().PhidgetDCMotor_getMaxDataInterval
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxDataInterval))

		if result > 0:
			raise PhidgetException(result)

		return _MaxDataInterval.value

	def getDataRate(self):
		_DataRate = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetDCMotor_getDataRate
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_DataRate))

		if result > 0:
			raise PhidgetException(result)

		return _DataRate.value

	def setDataRate(self, DataRate):
		_DataRate = ctypes.c_double(DataRate)

		__func = PhidgetSupport.getDll().PhidgetDCMotor_setDataRate
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _DataRate)

		if result > 0:
			raise PhidgetException(result)


	def getMinDataRate(self):
		_MinDataRate = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetDCMotor_getMinDataRate
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinDataRate))

		if result > 0:
			raise PhidgetException(result)

		return _MinDataRate.value

	def getMaxDataRate(self):
		_MaxDataRate = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetDCMotor_getMaxDataRate
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxDataRate))

		if result > 0:
			raise PhidgetException(result)

		return _MaxDataRate.value

	def enableFailsafe(self, failsafeTime):
		_failsafeTime = ctypes.c_uint32(failsafeTime)

		__func = PhidgetSupport.getDll().PhidgetDCMotor_enableFailsafe
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _failsafeTime)

		if result > 0:
			raise PhidgetException(result)


	def getMinFailsafeTime(self):
		_MinFailsafeTime = ctypes.c_uint32()

		__func = PhidgetSupport.getDll().PhidgetDCMotor_getMinFailsafeTime
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinFailsafeTime))

		if result > 0:
			raise PhidgetException(result)

		return _MinFailsafeTime.value

	def getMaxFailsafeTime(self):
		_MaxFailsafeTime = ctypes.c_uint32()

		__func = PhidgetSupport.getDll().PhidgetDCMotor_getMaxFailsafeTime
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxFailsafeTime))

		if result > 0:
			raise PhidgetException(result)

		return _MaxFailsafeTime.value

	def getFanMode(self):
		_FanMode = ctypes.c_int()

		__func = PhidgetSupport.getDll().PhidgetDCMotor_getFanMode
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_FanMode))

		if result > 0:
			raise PhidgetException(result)

		return _FanMode.value

	def setFanMode(self, FanMode):
		_FanMode = ctypes.c_int(FanMode)

		__func = PhidgetSupport.getDll().PhidgetDCMotor_setFanMode
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _FanMode)

		if result > 0:
			raise PhidgetException(result)


	def resetFailsafe(self):
		__func = PhidgetSupport.getDll().PhidgetDCMotor_resetFailsafe
		__func.restype = ctypes.c_int32
		result = __func(self.handle)

		if result > 0:
			raise PhidgetException(result)


	def getTargetBrakingStrength(self):
		_TargetBrakingStrength = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetDCMotor_getTargetBrakingStrength
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_TargetBrakingStrength))

		if result > 0:
			raise PhidgetException(result)

		return _TargetBrakingStrength.value

	def setTargetBrakingStrength(self, TargetBrakingStrength):
		_TargetBrakingStrength = ctypes.c_double(TargetBrakingStrength)

		__func = PhidgetSupport.getDll().PhidgetDCMotor_setTargetBrakingStrength
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _TargetBrakingStrength)

		if result > 0:
			raise PhidgetException(result)


	def getTargetVelocity(self):
		_TargetVelocity = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetDCMotor_getTargetVelocity
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_TargetVelocity))

		if result > 0:
			raise PhidgetException(result)

		return _TargetVelocity.value

	def setTargetVelocity(self, TargetVelocity):
		_TargetVelocity = ctypes.c_double(TargetVelocity)

		__func = PhidgetSupport.getDll().PhidgetDCMotor_setTargetVelocity
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _TargetVelocity)

		if result > 0:
			raise PhidgetException(result)


	def setTargetVelocity_async(self, TargetVelocity, asyncHandler):
		_TargetVelocity = ctypes.c_double(TargetVelocity)

		_ctx = ctypes.c_void_p()
		if asyncHandler != None:
			_ctx = ctypes.c_void_p(AsyncSupport.add(asyncHandler, self))
		_asyncHandler = AsyncSupport.getCallback()

		__func = PhidgetSupport.getDll().PhidgetDCMotor_setTargetVelocity_async
		__func(self.handle, _TargetVelocity, _asyncHandler, _ctx)


	def getVelocity(self):
		_Velocity = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetDCMotor_getVelocity
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_Velocity))

		if result > 0:
			raise PhidgetException(result)

		return _Velocity.value

	def getMinVelocity(self):
		_MinVelocity = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetDCMotor_getMinVelocity
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinVelocity))

		if result > 0:
			raise PhidgetException(result)

		return _MinVelocity.value

	def getMaxVelocity(self):
		_MaxVelocity = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetDCMotor_getMaxVelocity
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxVelocity))

		if result > 0:
			raise PhidgetException(result)

		return _MaxVelocity.value



import sys
import ctypes

from Phidget22.Unit import Unit

class UnitInfo(ctypes.Structure):
	_fields_ = [
		("_unit", ctypes.c_int),
		("_name", ctypes.c_char_p),
		("_symbol", ctypes.c_char_p),
	]

	def __init__(self):
		self.unit = 0
		self.name = ""
		self.symbol = ""

	def fromPython(self):
		self._unit = self.unit
		self._name = self.name.encode('utf-8')
		self._symbol = self.symbol.encode('utf-8')
		return self

	def toPython(self):
		if self._unit == None:
			self.unit = None
		else:
			self.unit = self._unit
		if self._name == None:
			self.name = None
		else:
			self.name = self._name.decode('utf-8')
		if self._symbol == None:
			self.symbol = None
		else:
			self.symbol = self._symbol.decode('utf-8')
		return self

	def __str__(self):
		return ("[UnitInfo] ("
			"unit: " + str(self.unit) + ", "
			"name: " + str(self.name) + ", "
			"symbol: " + str(self.symbol) + 
			")")



import sys
import ctypes
from Phidget22.PhidgetSupport import PhidgetSupport
from Phidget22.Async import *
from Phidget22.EncoderIOMode import EncoderIOMode
from Phidget22.PhidgetException import PhidgetException

from Phidget22.Phidget import Phidget

class Encoder(Phidget):

	def __init__(self):
		Phidget.__init__(self)
		self.handle = ctypes.c_void_p()

		if sys.platform == 'win32':
			self._PositionChangeFactory = ctypes.WINFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.c_int, ctypes.c_double, ctypes.c_int)
		else:
			self._PositionChangeFactory = ctypes.CFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.c_int, ctypes.c_double, ctypes.c_int)
		self._PositionChange = None
		self._onPositionChange = None

		__func = PhidgetSupport.getDll().PhidgetEncoder_create
		__func.restype = ctypes.c_int32
		res = __func(ctypes.byref(self.handle))

		if res > 0:
			raise PhidgetException(res)

	def __del__(self):
		Phidget.__del__(self)

	def _localPositionChangeEvent(self, handle, userPtr, positionChange, timeChange, indexTriggered):
		if self._PositionChange == None:
			return
		self._PositionChange(self, positionChange, timeChange, indexTriggered)

	def setOnPositionChangeHandler(self, handler):
		if handler == None:
			self._PositionChange = None
			self._onPositionChange = None
		else:
			self._PositionChange = handler
			self._onPositionChange = self._PositionChangeFactory(self._localPositionChangeEvent)

		try:
			__func = PhidgetSupport.getDll().PhidgetEncoder_setOnPositionChangeHandler
			__func.restype = ctypes.c_int32
			res = __func(self.handle, self._onPositionChange, None)
		except RuntimeError:
			self._PositionChange = None
			self._onPositionChange = None

	def setEnabled(self, Enabled):
		_Enabled = ctypes.c_int(Enabled)

		__func = PhidgetSupport.getDll().PhidgetEncoder_setEnabled
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _Enabled)

		if result > 0:
			raise PhidgetException(result)


	def getEnabled(self):
		_Enabled = ctypes.c_int()

		__func = PhidgetSupport.getDll().PhidgetEncoder_getEnabled
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_Enabled))

		if result > 0:
			raise PhidgetException(result)

		return bool(_Enabled.value)

	def getDataInterval(self):
		_DataInterval = ctypes.c_uint32()

		__func = PhidgetSupport.getDll().PhidgetEncoder_getDataInterval
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_DataInterval))

		if result > 0:
			raise PhidgetException(result)

		return _DataInterval.value

	def setDataInterval(self, DataInterval):
		_DataInterval = ctypes.c_uint32(DataInterval)

		__func = PhidgetSupport.getDll().PhidgetEncoder_setDataInterval
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _DataInterval)

		if result > 0:
			raise PhidgetException(result)


	def getMinDataInterval(self):
		_MinDataInterval = ctypes.c_uint32()

		__func = PhidgetSupport.getDll().PhidgetEncoder_getMinDataInterval
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinDataInterval))

		if result > 0:
			raise PhidgetException(result)

		return _MinDataInterval.value

	def getMaxDataInterval(self):
		_MaxDataInterval = ctypes.c_uint32()

		__func = PhidgetSupport.getDll().PhidgetEncoder_getMaxDataInterval
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxDataInterval))

		if result > 0:
			raise PhidgetException(result)

		return _MaxDataInterval.value

	def getDataRate(self):
		_DataRate = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetEncoder_getDataRate
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_DataRate))

		if result > 0:
			raise PhidgetException(result)

		return _DataRate.value

	def setDataRate(self, DataRate):
		_DataRate = ctypes.c_double(DataRate)

		__func = PhidgetSupport.getDll().PhidgetEncoder_setDataRate
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _DataRate)

		if result > 0:
			raise PhidgetException(result)


	def getMinDataRate(self):
		_MinDataRate = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetEncoder_getMinDataRate
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinDataRate))

		if result > 0:
			raise PhidgetException(result)

		return _MinDataRate.value

	def getMaxDataRate(self):
		_MaxDataRate = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetEncoder_getMaxDataRate
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxDataRate))

		if result > 0:
			raise PhidgetException(result)

		return _MaxDataRate.value

	def getIndexPosition(self):
		_IndexPosition = ctypes.c_int64()

		__func = PhidgetSupport.getDll().PhidgetEncoder_getIndexPosition
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_IndexPosition))

		if result > 0:
			raise PhidgetException(result)

		return _IndexPosition.value

	def getIOMode(self):
		_IOMode = ctypes.c_int()

		__func = PhidgetSupport.getDll().PhidgetEncoder_getIOMode
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_IOMode))

		if result > 0:
			raise PhidgetException(result)

		return _IOMode.value

	def setIOMode(self, IOMode):
		_IOMode = ctypes.c_int(IOMode)

		__func = PhidgetSupport.getDll().PhidgetEncoder_setIOMode
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _IOMode)

		if result > 0:
			raise PhidgetException(result)


	def getPosition(self):
		_Position = ctypes.c_int64()

		__func = PhidgetSupport.getDll().PhidgetEncoder_getPosition
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_Position))

		if result > 0:
			raise PhidgetException(result)

		return _Position.value

	def setPosition(self, Position):
		_Position = ctypes.c_int64(Position)

		__func = PhidgetSupport.getDll().PhidgetEncoder_setPosition
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _Position)

		if result > 0:
			raise PhidgetException(result)


	def getPositionChangeTrigger(self):
		_PositionChangeTrigger = ctypes.c_uint32()

		__func = PhidgetSupport.getDll().PhidgetEncoder_getPositionChangeTrigger
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_PositionChangeTrigger))

		if result > 0:
			raise PhidgetException(result)

		return _PositionChangeTrigger.value

	def setPositionChangeTrigger(self, PositionChangeTrigger):
		_PositionChangeTrigger = ctypes.c_uint32(PositionChangeTrigger)

		__func = PhidgetSupport.getDll().PhidgetEncoder_setPositionChangeTrigger
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _PositionChangeTrigger)

		if result > 0:
			raise PhidgetException(result)


	def getMinPositionChangeTrigger(self):
		_MinPositionChangeTrigger = ctypes.c_uint32()

		__func = PhidgetSupport.getDll().PhidgetEncoder_getMinPositionChangeTrigger
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinPositionChangeTrigger))

		if result > 0:
			raise PhidgetException(result)

		return _MinPositionChangeTrigger.value

	def getMaxPositionChangeTrigger(self):
		_MaxPositionChangeTrigger = ctypes.c_uint32()

		__func = PhidgetSupport.getDll().PhidgetEncoder_getMaxPositionChangeTrigger
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxPositionChangeTrigger))

		if result > 0:
			raise PhidgetException(result)

		return _MaxPositionChangeTrigger.value



import sys
import ctypes
class MeshMode:
	# Router mode
	MESHMODE_ROUTER = 1
	# Sleepy end device mode
	MESHMODE_SLEEPYENDDEVICE = 2

	@classmethod
	def getName(self, val):
		if val == self.MESHMODE_ROUTER:
			return "MESHMODE_ROUTER"
		if val == self.MESHMODE_SLEEPYENDDEVICE:
			return "MESHMODE_SLEEPYENDDEVICE"
		return "<invalid enumeration value>"



import sys
import ctypes
from Phidget22.PhidgetSupport import PhidgetSupport
from Phidget22.Async import *
from Phidget22.ChannelClass import ChannelClass
from Phidget22.ChannelSubclass import ChannelSubclass
from Phidget22.DeviceClass import DeviceClass
from Phidget22.DeviceID import DeviceID
from Phidget22.ErrorEventCode import ErrorEventCode
from Phidget22.PhidgetException import PhidgetException

class Phidget:

	def __init__(self):
		self.handle = ctypes.c_void_p()

		if sys.platform == 'win32':
			self._AttachFactory = ctypes.WINFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p)
		else:
			self._AttachFactory = ctypes.CFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p)
		self._Attach = None
		self._onAttach = None

		if sys.platform == 'win32':
			self._DetachFactory = ctypes.WINFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p)
		else:
			self._DetachFactory = ctypes.CFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p)
		self._Detach = None
		self._onDetach = None

		if sys.platform == 'win32':
			self._ErrorFactory = ctypes.WINFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.c_int, ctypes.c_char_p)
		else:
			self._ErrorFactory = ctypes.CFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.c_int, ctypes.c_char_p)
		self._Error = None
		self._onError = None

		if sys.platform == 'win32':
			self._PropertyChangeFactory = ctypes.WINFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.c_char_p)
		else:
			self._PropertyChangeFactory = ctypes.CFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.c_char_p)
		self._PropertyChange = None
		self._onPropertyChange = None


	def __eq__(self, other):
		return hasattr(other, 'handle') and self.handle.value == other.handle.value

	def __hash__(self):
		return self.handle.value

	def __str__(self):
		_value = (ctypes.c_char * 65536)()
		_valueLen = ctypes.c_int32(65536)
		if self.getIsChannel():
			__func = PhidgetSupport.getDll().channelInfo
		else:
			__func = PhidgetSupport.getDll().deviceInfo
		result = __func(self.handle, ctypes.byref(_value), _valueLen)
		return _value.value.decode('utf- 8')

	def __del__(self):
		__func = PhidgetSupport.getDll().Phidget_delete
		__func.restype = ctypes.c_int32
		res = __func(ctypes.byref(self.handle))
		self.handle = None
		if res > 0:
			raise PhidgetException(res)

	def _localAttachEvent(self, handle, userPtr):
		if self._Attach == None:
			return
		self._Attach(self)

	def setOnAttachHandler(self, handler):
		if handler == None:
			self._Attach = None
			self._onAttach = None
		else:
			self._Attach = handler
			self._onAttach = self._AttachFactory(self._localAttachEvent)

		try:
			__func = PhidgetSupport.getDll().Phidget_setOnAttachHandler
			__func.restype = ctypes.c_int32
			res = __func(self.handle, self._onAttach, None)
		except RuntimeError:
			self._Attach = None
			self._onAttach = None

	def _localDetachEvent(self, handle, userPtr):
		if self._Detach == None:
			return
		self._Detach(self)

	def setOnDetachHandler(self, handler):
		if handler == None:
			self._Detach = None
			self._onDetach = None
		else:
			self._Detach = handler
			self._onDetach = self._DetachFactory(self._localDetachEvent)

		try:
			__func = PhidgetSupport.getDll().Phidget_setOnDetachHandler
			__func.restype = ctypes.c_int32
			res = __func(self.handle, self._onDetach, None)
		except RuntimeError:
			self._Detach = None
			self._onDetach = None

	def _localErrorEvent(self, handle, userPtr, Code, Description):
		if self._Error == None:
			return
		Description = Description.decode('utf-8')
		self._Error(self, Code, Description)

	def setOnErrorHandler(self, handler):
		if handler == None:
			self._Error = None
			self._onError = None
		else:
			self._Error = handler
			self._onError = self._ErrorFactory(self._localErrorEvent)

		try:
			__func = PhidgetSupport.getDll().Phidget_setOnErrorHandler
			__func.restype = ctypes.c_int32
			res = __func(self.handle, self._onError, None)
		except RuntimeError:
			self._Error = None
			self._onError = None

	def _localPropertyChangeEvent(self, handle, userPtr, propertyName):
		if self._PropertyChange == None:
			return
		propertyName = propertyName.decode('utf-8')
		self._PropertyChange(self, propertyName)

	def setOnPropertyChangeHandler(self, handler):
		if handler == None:
			self._PropertyChange = None
			self._onPropertyChange = None
		else:
			self._PropertyChange = handler
			self._onPropertyChange = self._PropertyChangeFactory(self._localPropertyChangeEvent)

		try:
			__func = PhidgetSupport.getDll().Phidget_setOnPropertyChangeHandler
			__func.restype = ctypes.c_int32
			res = __func(self.handle, self._onPropertyChange, None)
		except RuntimeError:
			self._PropertyChange = None
			self._onPropertyChange = None

	@staticmethod
	def finalize(flags):
		_flags = ctypes.c_int32(flags)

		__func = PhidgetSupport.getDll().Phidget_finalize
		__func.restype = ctypes.c_int32
		result = __func(_flags)

		if result > 0:
			raise PhidgetException(result)


	@staticmethod
	def getLibraryVersion():
		_LibraryVersion = ctypes.c_char_p()

		__func = PhidgetSupport.getDll().Phidget_getLibraryVersion
		__func.restype = ctypes.c_int32
		result = __func(ctypes.byref(_LibraryVersion))

		if result > 0:
			raise PhidgetException(result)

		return _LibraryVersion.value.decode('utf-8')

	@staticmethod
	def getLibraryVersionNumber():
		_LibraryVersionNumber = ctypes.c_char_p()

		__func = PhidgetSupport.getDll().Phidget_getLibraryVersionNumber
		__func.restype = ctypes.c_int32
		result = __func(ctypes.byref(_LibraryVersionNumber))

		if result > 0:
			raise PhidgetException(result)

		return _LibraryVersionNumber.value.decode('utf-8')

	@staticmethod
	def resetLibrary():
		__func = PhidgetSupport.getDll().Phidget_resetLibrary
		__func.restype = ctypes.c_int32
		result = __func()

		if result > 0:
			raise PhidgetException(result)


	def getAttached(self):
		_Attached = ctypes.c_int()

		__func = PhidgetSupport.getDll().Phidget_getAttached
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_Attached))

		if result > 0:
			raise PhidgetException(result)

		return bool(_Attached.value)

	def getChannel(self):
		_Channel = ctypes.c_int()

		__func = PhidgetSupport.getDll().Phidget_getChannel
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_Channel))

		if result > 0:
			raise PhidgetException(result)

		return _Channel.value

	def setChannel(self, Channel):
		_Channel = ctypes.c_int(Channel)

		__func = PhidgetSupport.getDll().Phidget_setChannel
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _Channel)

		if result > 0:
			raise PhidgetException(result)


	def getChannelClass(self):
		_ChannelClass = ctypes.c_int()

		__func = PhidgetSupport.getDll().Phidget_getChannelClass
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_ChannelClass))

		if result > 0:
			raise PhidgetException(result)

		return _ChannelClass.value

	def getChannelClassName(self):
		_ChannelClassName = ctypes.c_char_p()

		__func = PhidgetSupport.getDll().Phidget_getChannelClassName
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_ChannelClassName))

		if result > 0:
			raise PhidgetException(result)

		return _ChannelClassName.value.decode('utf-8')

	def getChannelName(self):
		_ChannelName = ctypes.c_char_p()

		__func = PhidgetSupport.getDll().Phidget_getChannelName
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_ChannelName))

		if result > 0:
			raise PhidgetException(result)

		return _ChannelName.value.decode('utf-8')

	def getChannelSubclass(self):
		_ChannelSubclass = ctypes.c_int()

		__func = PhidgetSupport.getDll().Phidget_getChannelSubclass
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_ChannelSubclass))

		if result > 0:
			raise PhidgetException(result)

		return _ChannelSubclass.value

	def close(self):
		__func = PhidgetSupport.getDll().Phidget_close
		__func.restype = ctypes.c_int32
		result = __func(self.handle)

		if result > 0:
			raise PhidgetException(result)


	def getDeviceChannelCount(self, cls):
		_cls = ctypes.c_int(cls)
		_count = ctypes.c_uint32()

		__func = PhidgetSupport.getDll().Phidget_getDeviceChannelCount
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _cls, ctypes.byref(_count))

		if result > 0:
			raise PhidgetException(result)

		return _count.value

	def getDeviceClass(self):
		_DeviceClass = ctypes.c_int()

		__func = PhidgetSupport.getDll().Phidget_getDeviceClass
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_DeviceClass))

		if result > 0:
			raise PhidgetException(result)

		return _DeviceClass.value

	def getDeviceClassName(self):
		_DeviceClassName = ctypes.c_char_p()

		__func = PhidgetSupport.getDll().Phidget_getDeviceClassName
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_DeviceClassName))

		if result > 0:
			raise PhidgetException(result)

		return _DeviceClassName.value.decode('utf-8')

	def getDeviceID(self):
		_DeviceID = ctypes.c_int()

		__func = PhidgetSupport.getDll().Phidget_getDeviceID
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_DeviceID))

		if result > 0:
			raise PhidgetException(result)

		return _DeviceID.value

	def getDeviceLabel(self):
		_DeviceLabel = ctypes.c_char_p()

		__func = PhidgetSupport.getDll().Phidget_getDeviceLabel
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_DeviceLabel))

		if result > 0:
			raise PhidgetException(result)

		return _DeviceLabel.value.decode('utf-8')

	def setDeviceLabel(self, DeviceLabel):
		_DeviceLabel = ctypes.create_string_buffer(DeviceLabel.encode('utf-8'))

		__func = PhidgetSupport.getDll().Phidget_setDeviceLabel
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_DeviceLabel))

		if result > 0:
			raise PhidgetException(result)


	def getDeviceName(self):
		_DeviceName = ctypes.c_char_p()

		__func = PhidgetSupport.getDll().Phidget_getDeviceName
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_DeviceName))

		if result > 0:
			raise PhidgetException(result)

		return _DeviceName.value.decode('utf-8')

	def getDeviceSerialNumber(self):
		_DeviceSerialNumber = ctypes.c_int32()

		__func = PhidgetSupport.getDll().Phidget_getDeviceSerialNumber
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_DeviceSerialNumber))

		if result > 0:
			raise PhidgetException(result)

		return _DeviceSerialNumber.value

	def setDeviceSerialNumber(self, DeviceSerialNumber):
		_DeviceSerialNumber = ctypes.c_int32(DeviceSerialNumber)

		__func = PhidgetSupport.getDll().Phidget_setDeviceSerialNumber
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _DeviceSerialNumber)

		if result > 0:
			raise PhidgetException(result)


	def getDeviceSKU(self):
		_DeviceSKU = ctypes.c_char_p()

		__func = PhidgetSupport.getDll().Phidget_getDeviceSKU
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_DeviceSKU))

		if result > 0:
			raise PhidgetException(result)

		return _DeviceSKU.value.decode('utf-8')

	def getDeviceVersion(self):
		_DeviceVersion = ctypes.c_int()

		__func = PhidgetSupport.getDll().Phidget_getDeviceVersion
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_DeviceVersion))

		if result > 0:
			raise PhidgetException(result)

		return _DeviceVersion.value

	def getHub(self):
		_Hub = ctypes.c_void_p()

		__func = PhidgetSupport.getDll().Phidget_getHub
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_Hub))

		if result > 0:
			raise PhidgetException(result)

		__Hub = Phidget()
		__Hub.handle = _Hub
		return __Hub

	def getHubPort(self):
		_HubPort = ctypes.c_int()

		__func = PhidgetSupport.getDll().Phidget_getHubPort
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_HubPort))

		if result > 0:
			raise PhidgetException(result)

		return _HubPort.value

	def setHubPort(self, HubPort):
		_HubPort = ctypes.c_int(HubPort)

		__func = PhidgetSupport.getDll().Phidget_setHubPort
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _HubPort)

		if result > 0:
			raise PhidgetException(result)


	def getHubPortCount(self):
		_HubPortCount = ctypes.c_int()

		__func = PhidgetSupport.getDll().Phidget_getHubPortCount
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_HubPortCount))

		if result > 0:
			raise PhidgetException(result)

		return _HubPortCount.value

	def getHubPortSpeed(self):
		_HubPortSpeed = ctypes.c_uint32()

		__func = PhidgetSupport.getDll().Phidget_getHubPortSpeed
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_HubPortSpeed))

		if result > 0:
			raise PhidgetException(result)

		return _HubPortSpeed.value

	def setHubPortSpeed(self, HubPortSpeed):
		_HubPortSpeed = ctypes.c_uint32(HubPortSpeed)

		__func = PhidgetSupport.getDll().Phidget_setHubPortSpeed
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _HubPortSpeed)

		if result > 0:
			raise PhidgetException(result)


	def getMaxHubPortSpeed(self):
		_MaxHubPortSpeed = ctypes.c_uint32()

		__func = PhidgetSupport.getDll().Phidget_getMaxHubPortSpeed
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxHubPortSpeed))

		if result > 0:
			raise PhidgetException(result)

		return _MaxHubPortSpeed.value

	def getHubPortSupportsAutoSetSpeed(self):
		_HubPortSupportsAutoSetSpeed = ctypes.c_int()

		__func = PhidgetSupport.getDll().Phidget_getHubPortSupportsAutoSetSpeed
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_HubPortSupportsAutoSetSpeed))

		if result > 0:
			raise PhidgetException(result)

		return bool(_HubPortSupportsAutoSetSpeed.value)

	def getHubPortSupportsSetSpeed(self):
		_HubPortSupportsSetSpeed = ctypes.c_int()

		__func = PhidgetSupport.getDll().Phidget_getHubPortSupportsSetSpeed
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_HubPortSupportsSetSpeed))

		if result > 0:
			raise PhidgetException(result)

		return bool(_HubPortSupportsSetSpeed.value)

	def getIsChannel(self):
		_IsChannel = ctypes.c_int()

		__func = PhidgetSupport.getDll().Phidget_getIsChannel
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_IsChannel))

		if result > 0:
			raise PhidgetException(result)

		return bool(_IsChannel.value)

	def getIsHubPortDevice(self):
		_IsHubPortDevice = ctypes.c_int()

		__func = PhidgetSupport.getDll().Phidget_getIsHubPortDevice
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_IsHubPortDevice))

		if result > 0:
			raise PhidgetException(result)

		return bool(_IsHubPortDevice.value)

	def setIsHubPortDevice(self, IsHubPortDevice):
		_IsHubPortDevice = ctypes.c_int(IsHubPortDevice)

		__func = PhidgetSupport.getDll().Phidget_setIsHubPortDevice
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _IsHubPortDevice)

		if result > 0:
			raise PhidgetException(result)


	def getIsLocal(self):
		_IsLocal = ctypes.c_int()

		__func = PhidgetSupport.getDll().Phidget_getIsLocal
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_IsLocal))

		if result > 0:
			raise PhidgetException(result)

		return bool(_IsLocal.value)

	def setIsLocal(self, IsLocal):
		_IsLocal = ctypes.c_int(IsLocal)

		__func = PhidgetSupport.getDll().Phidget_setIsLocal
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _IsLocal)

		if result > 0:
			raise PhidgetException(result)


	def getIsOpen(self):
		_IsOpen = ctypes.c_int()

		__func = PhidgetSupport.getDll().Phidget_getIsOpen
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_IsOpen))

		if result > 0:
			raise PhidgetException(result)

		return bool(_IsOpen.value)

	def getIsRemote(self):
		_IsRemote = ctypes.c_int()

		__func = PhidgetSupport.getDll().Phidget_getIsRemote
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_IsRemote))

		if result > 0:
			raise PhidgetException(result)

		return bool(_IsRemote.value)

	def setIsRemote(self, IsRemote):
		_IsRemote = ctypes.c_int(IsRemote)

		__func = PhidgetSupport.getDll().Phidget_setIsRemote
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _IsRemote)

		if result > 0:
			raise PhidgetException(result)


	def open(self):
		__func = PhidgetSupport.getDll().Phidget_open
		__func.restype = ctypes.c_int32
		result = __func(self.handle)

		if result > 0:
			raise PhidgetException(result)


	def openWaitForAttachment(self, timeout):
		_timeout = ctypes.c_uint32(timeout)

		__func = PhidgetSupport.getDll().Phidget_openWaitForAttachment
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _timeout)

		if result > 0:
			raise PhidgetException(result)


	def getParent(self):
		_Parent = ctypes.c_void_p()

		__func = PhidgetSupport.getDll().Phidget_getParent
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_Parent))

		if result > 0:
			raise PhidgetException(result)

		__Parent = Phidget()
		__Parent.handle = _Parent
		return __Parent

	def getServerHostname(self):
		_ServerHostname = ctypes.c_char_p()

		__func = PhidgetSupport.getDll().Phidget_getServerHostname
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_ServerHostname))

		if result > 0:
			raise PhidgetException(result)

		return _ServerHostname.value.decode('utf-8')

	def getServerName(self):
		_ServerName = ctypes.c_char_p()

		__func = PhidgetSupport.getDll().Phidget_getServerName
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_ServerName))

		if result > 0:
			raise PhidgetException(result)

		return _ServerName.value.decode('utf-8')

	def setServerName(self, ServerName):
		_ServerName = ctypes.create_string_buffer(ServerName.encode('utf-8'))

		__func = PhidgetSupport.getDll().Phidget_setServerName
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_ServerName))

		if result > 0:
			raise PhidgetException(result)


	def getServerPeerName(self):
		_ServerPeerName = ctypes.c_char_p()

		__func = PhidgetSupport.getDll().Phidget_getServerPeerName
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_ServerPeerName))

		if result > 0:
			raise PhidgetException(result)

		return _ServerPeerName.value.decode('utf-8')

	def getServerUniqueName(self):
		_ServerUniqueName = ctypes.c_char_p()

		__func = PhidgetSupport.getDll().Phidget_getServerUniqueName
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_ServerUniqueName))

		if result > 0:
			raise PhidgetException(result)

		return _ServerUniqueName.value.decode('utf-8')

	def getMaxVINTDeviceSpeed(self):
		_MaxVINTDeviceSpeed = ctypes.c_uint32()

		__func = PhidgetSupport.getDll().Phidget_getMaxVINTDeviceSpeed
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxVINTDeviceSpeed))

		if result > 0:
			raise PhidgetException(result)

		return _MaxVINTDeviceSpeed.value

	def getVINTDeviceSupportsAutoSetSpeed(self):
		_VINTDeviceSupportsAutoSetSpeed = ctypes.c_int()

		__func = PhidgetSupport.getDll().Phidget_getVINTDeviceSupportsAutoSetSpeed
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_VINTDeviceSupportsAutoSetSpeed))

		if result > 0:
			raise PhidgetException(result)

		return bool(_VINTDeviceSupportsAutoSetSpeed.value)

	def getVINTDeviceSupportsSetSpeed(self):
		_VINTDeviceSupportsSetSpeed = ctypes.c_int()

		__func = PhidgetSupport.getDll().Phidget_getVINTDeviceSupportsSetSpeed
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_VINTDeviceSupportsSetSpeed))

		if result > 0:
			raise PhidgetException(result)

		return bool(_VINTDeviceSupportsSetSpeed.value)

	def writeDeviceLabel(self, deviceLabel):
		_deviceLabel = ctypes.create_string_buffer(deviceLabel.encode('utf-8'))

		__func = PhidgetSupport.getDll().Phidget_writeDeviceLabel
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_deviceLabel))

		if result > 0:
			raise PhidgetException(result)


	ANY_SERIAL_NUMBER = -1

	ANY_HUB_PORT = -1

	ANY_CHANNEL = -1

	ANY_LABEL = None

	INFINITE_TIMEOUT = 0

	DEFAULT_TIMEOUT = 1000

	AUTO_HUBPORTSPEED = 0



import threading
import sys
import ctypes
from ctypes import *
import os

class PhidgetSupport:
	__dll = None

	@staticmethod
	def getDll():
		if PhidgetSupport.__dll is None:
			if sys.platform == 'win32':
				# Load phidget22.dll from within the Python package itself
				libs_path = os.path.join(os.path.dirname(os.path.abspath(__file__)), ".libs")
				if os.path.exists(os.path.join(libs_path, "phidget22.dll")):
					PhidgetSupport.__dll = windll.LoadLibrary(os.path.join(libs_path, "phidget22.dll"))
				else:
					PhidgetSupport.__dll = windll.LoadLibrary("phidget22.dll")
			elif sys.platform == 'darwin':
				PhidgetSupport.__dll = cdll.LoadLibrary("/Library/Frameworks/Phidget22.framework/Versions/Current/Phidget22")
			else:
				PhidgetSupport.__dll = cdll.LoadLibrary("libphidget22.so.0")
		return PhidgetSupport.__dll

	def __init__(self):
		self.handle = None

	def __del__(self):
		pass

	@staticmethod
	def versionChecked_ord(character):
		if(sys.version_info[0] < 3):
			return character
		else:
			return ord(character)



import sys
import ctypes
from Phidget22.PhidgetSupport import PhidgetSupport
from Phidget22.Async import *
from Phidget22.RTDType import RTDType
from Phidget22.RTDWireSetup import RTDWireSetup
from Phidget22.ThermocoupleType import ThermocoupleType
from Phidget22.PhidgetException import PhidgetException

from Phidget22.Phidget import Phidget

class TemperatureSensor(Phidget):

	def __init__(self):
		Phidget.__init__(self)
		self.handle = ctypes.c_void_p()

		if sys.platform == 'win32':
			self._TemperatureChangeFactory = ctypes.WINFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.c_double)
		else:
			self._TemperatureChangeFactory = ctypes.CFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.c_double)
		self._TemperatureChange = None
		self._onTemperatureChange = None

		__func = PhidgetSupport.getDll().PhidgetTemperatureSensor_create
		__func.restype = ctypes.c_int32
		res = __func(ctypes.byref(self.handle))

		if res > 0:
			raise PhidgetException(res)

	def __del__(self):
		Phidget.__del__(self)

	def _localTemperatureChangeEvent(self, handle, userPtr, temperature):
		if self._TemperatureChange == None:
			return
		self._TemperatureChange(self, temperature)

	def setOnTemperatureChangeHandler(self, handler):
		if handler == None:
			self._TemperatureChange = None
			self._onTemperatureChange = None
		else:
			self._TemperatureChange = handler
			self._onTemperatureChange = self._TemperatureChangeFactory(self._localTemperatureChangeEvent)

		try:
			__func = PhidgetSupport.getDll().PhidgetTemperatureSensor_setOnTemperatureChangeHandler
			__func.restype = ctypes.c_int32
			res = __func(self.handle, self._onTemperatureChange, None)
		except RuntimeError:
			self._TemperatureChange = None
			self._onTemperatureChange = None

	def getDataInterval(self):
		_DataInterval = ctypes.c_uint32()

		__func = PhidgetSupport.getDll().PhidgetTemperatureSensor_getDataInterval
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_DataInterval))

		if result > 0:
			raise PhidgetException(result)

		return _DataInterval.value

	def setDataInterval(self, DataInterval):
		_DataInterval = ctypes.c_uint32(DataInterval)

		__func = PhidgetSupport.getDll().PhidgetTemperatureSensor_setDataInterval
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _DataInterval)

		if result > 0:
			raise PhidgetException(result)


	def getMinDataInterval(self):
		_MinDataInterval = ctypes.c_uint32()

		__func = PhidgetSupport.getDll().PhidgetTemperatureSensor_getMinDataInterval
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinDataInterval))

		if result > 0:
			raise PhidgetException(result)

		return _MinDataInterval.value

	def getMaxDataInterval(self):
		_MaxDataInterval = ctypes.c_uint32()

		__func = PhidgetSupport.getDll().PhidgetTemperatureSensor_getMaxDataInterval
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxDataInterval))

		if result > 0:
			raise PhidgetException(result)

		return _MaxDataInterval.value

	def getDataRate(self):
		_DataRate = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetTemperatureSensor_getDataRate
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_DataRate))

		if result > 0:
			raise PhidgetException(result)

		return _DataRate.value

	def setDataRate(self, DataRate):
		_DataRate = ctypes.c_double(DataRate)

		__func = PhidgetSupport.getDll().PhidgetTemperatureSensor_setDataRate
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _DataRate)

		if result > 0:
			raise PhidgetException(result)


	def getMinDataRate(self):
		_MinDataRate = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetTemperatureSensor_getMinDataRate
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinDataRate))

		if result > 0:
			raise PhidgetException(result)

		return _MinDataRate.value

	def getMaxDataRate(self):
		_MaxDataRate = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetTemperatureSensor_getMaxDataRate
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxDataRate))

		if result > 0:
			raise PhidgetException(result)

		return _MaxDataRate.value

	def getRTDType(self):
		_RTDType = ctypes.c_int()

		__func = PhidgetSupport.getDll().PhidgetTemperatureSensor_getRTDType
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_RTDType))

		if result > 0:
			raise PhidgetException(result)

		return _RTDType.value

	def setRTDType(self, RTDType):
		_RTDType = ctypes.c_int(RTDType)

		__func = PhidgetSupport.getDll().PhidgetTemperatureSensor_setRTDType
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _RTDType)

		if result > 0:
			raise PhidgetException(result)


	def getRTDWireSetup(self):
		_RTDWireSetup = ctypes.c_int()

		__func = PhidgetSupport.getDll().PhidgetTemperatureSensor_getRTDWireSetup
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_RTDWireSetup))

		if result > 0:
			raise PhidgetException(result)

		return _RTDWireSetup.value

	def setRTDWireSetup(self, RTDWireSetup):
		_RTDWireSetup = ctypes.c_int(RTDWireSetup)

		__func = PhidgetSupport.getDll().PhidgetTemperatureSensor_setRTDWireSetup
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _RTDWireSetup)

		if result > 0:
			raise PhidgetException(result)


	def getTemperature(self):
		_Temperature = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetTemperatureSensor_getTemperature
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_Temperature))

		if result > 0:
			raise PhidgetException(result)

		return _Temperature.value

	def getMinTemperature(self):
		_MinTemperature = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetTemperatureSensor_getMinTemperature
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinTemperature))

		if result > 0:
			raise PhidgetException(result)

		return _MinTemperature.value

	def getMaxTemperature(self):
		_MaxTemperature = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetTemperatureSensor_getMaxTemperature
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxTemperature))

		if result > 0:
			raise PhidgetException(result)

		return _MaxTemperature.value

	def getTemperatureChangeTrigger(self):
		_TemperatureChangeTrigger = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetTemperatureSensor_getTemperatureChangeTrigger
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_TemperatureChangeTrigger))

		if result > 0:
			raise PhidgetException(result)

		return _TemperatureChangeTrigger.value

	def setTemperatureChangeTrigger(self, TemperatureChangeTrigger):
		_TemperatureChangeTrigger = ctypes.c_double(TemperatureChangeTrigger)

		__func = PhidgetSupport.getDll().PhidgetTemperatureSensor_setTemperatureChangeTrigger
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _TemperatureChangeTrigger)

		if result > 0:
			raise PhidgetException(result)


	def getMinTemperatureChangeTrigger(self):
		_MinTemperatureChangeTrigger = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetTemperatureSensor_getMinTemperatureChangeTrigger
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinTemperatureChangeTrigger))

		if result > 0:
			raise PhidgetException(result)

		return _MinTemperatureChangeTrigger.value

	def getMaxTemperatureChangeTrigger(self):
		_MaxTemperatureChangeTrigger = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetTemperatureSensor_getMaxTemperatureChangeTrigger
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxTemperatureChangeTrigger))

		if result > 0:
			raise PhidgetException(result)

		return _MaxTemperatureChangeTrigger.value

	def getThermocoupleType(self):
		_ThermocoupleType = ctypes.c_int()

		__func = PhidgetSupport.getDll().PhidgetTemperatureSensor_getThermocoupleType
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_ThermocoupleType))

		if result > 0:
			raise PhidgetException(result)

		return _ThermocoupleType.value

	def setThermocoupleType(self, ThermocoupleType):
		_ThermocoupleType = ctypes.c_int(ThermocoupleType)

		__func = PhidgetSupport.getDll().PhidgetTemperatureSensor_setThermocoupleType
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _ThermocoupleType)

		if result > 0:
			raise PhidgetException(result)




import sys
import ctypes
from Phidget22.PhidgetSupport import PhidgetSupport
from Phidget22.Async import *
from Phidget22.FilterType import FilterType
from Phidget22.InputMode import InputMode
from Phidget22.PowerSupply import PowerSupply
from Phidget22.PhidgetException import PhidgetException

from Phidget22.Phidget import Phidget

class FrequencyCounter(Phidget):

	def __init__(self):
		Phidget.__init__(self)
		self.handle = ctypes.c_void_p()

		if sys.platform == 'win32':
			self._CountChangeFactory = ctypes.WINFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.c_uint64, ctypes.c_double)
		else:
			self._CountChangeFactory = ctypes.CFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.c_uint64, ctypes.c_double)
		self._CountChange = None
		self._onCountChange = None

		if sys.platform == 'win32':
			self._FrequencyChangeFactory = ctypes.WINFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.c_double)
		else:
			self._FrequencyChangeFactory = ctypes.CFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.c_double)
		self._FrequencyChange = None
		self._onFrequencyChange = None

		__func = PhidgetSupport.getDll().PhidgetFrequencyCounter_create
		__func.restype = ctypes.c_int32
		res = __func(ctypes.byref(self.handle))

		if res > 0:
			raise PhidgetException(res)

	def __del__(self):
		Phidget.__del__(self)

	def _localCountChangeEvent(self, handle, userPtr, counts, timeChange):
		if self._CountChange == None:
			return
		self._CountChange(self, counts, timeChange)

	def setOnCountChangeHandler(self, handler):
		if handler == None:
			self._CountChange = None
			self._onCountChange = None
		else:
			self._CountChange = handler
			self._onCountChange = self._CountChangeFactory(self._localCountChangeEvent)

		try:
			__func = PhidgetSupport.getDll().PhidgetFrequencyCounter_setOnCountChangeHandler
			__func.restype = ctypes.c_int32
			res = __func(self.handle, self._onCountChange, None)
		except RuntimeError:
			self._CountChange = None
			self._onCountChange = None

	def _localFrequencyChangeEvent(self, handle, userPtr, frequency):
		if self._FrequencyChange == None:
			return
		self._FrequencyChange(self, frequency)

	def setOnFrequencyChangeHandler(self, handler):
		if handler == None:
			self._FrequencyChange = None
			self._onFrequencyChange = None
		else:
			self._FrequencyChange = handler
			self._onFrequencyChange = self._FrequencyChangeFactory(self._localFrequencyChangeEvent)

		try:
			__func = PhidgetSupport.getDll().PhidgetFrequencyCounter_setOnFrequencyChangeHandler
			__func.restype = ctypes.c_int32
			res = __func(self.handle, self._onFrequencyChange, None)
		except RuntimeError:
			self._FrequencyChange = None
			self._onFrequencyChange = None

	def getCount(self):
		_Count = ctypes.c_uint64()

		__func = PhidgetSupport.getDll().PhidgetFrequencyCounter_getCount
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_Count))

		if result > 0:
			raise PhidgetException(result)

		return _Count.value

	def setEnabled(self, Enabled):
		_Enabled = ctypes.c_int(Enabled)

		__func = PhidgetSupport.getDll().PhidgetFrequencyCounter_setEnabled
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _Enabled)

		if result > 0:
			raise PhidgetException(result)


	def getEnabled(self):
		_Enabled = ctypes.c_int()

		__func = PhidgetSupport.getDll().PhidgetFrequencyCounter_getEnabled
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_Enabled))

		if result > 0:
			raise PhidgetException(result)

		return bool(_Enabled.value)

	def getDataInterval(self):
		_DataInterval = ctypes.c_uint32()

		__func = PhidgetSupport.getDll().PhidgetFrequencyCounter_getDataInterval
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_DataInterval))

		if result > 0:
			raise PhidgetException(result)

		return _DataInterval.value

	def setDataInterval(self, DataInterval):
		_DataInterval = ctypes.c_uint32(DataInterval)

		__func = PhidgetSupport.getDll().PhidgetFrequencyCounter_setDataInterval
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _DataInterval)

		if result > 0:
			raise PhidgetException(result)


	def getMinDataInterval(self):
		_MinDataInterval = ctypes.c_uint32()

		__func = PhidgetSupport.getDll().PhidgetFrequencyCounter_getMinDataInterval
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinDataInterval))

		if result > 0:
			raise PhidgetException(result)

		return _MinDataInterval.value

	def getMaxDataInterval(self):
		_MaxDataInterval = ctypes.c_uint32()

		__func = PhidgetSupport.getDll().PhidgetFrequencyCounter_getMaxDataInterval
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxDataInterval))

		if result > 0:
			raise PhidgetException(result)

		return _MaxDataInterval.value

	def getDataRate(self):
		_DataRate = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetFrequencyCounter_getDataRate
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_DataRate))

		if result > 0:
			raise PhidgetException(result)

		return _DataRate.value

	def setDataRate(self, DataRate):
		_DataRate = ctypes.c_double(DataRate)

		__func = PhidgetSupport.getDll().PhidgetFrequencyCounter_setDataRate
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _DataRate)

		if result > 0:
			raise PhidgetException(result)


	def getMinDataRate(self):
		_MinDataRate = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetFrequencyCounter_getMinDataRate
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinDataRate))

		if result > 0:
			raise PhidgetException(result)

		return _MinDataRate.value

	def getMaxDataRate(self):
		_MaxDataRate = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetFrequencyCounter_getMaxDataRate
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxDataRate))

		if result > 0:
			raise PhidgetException(result)

		return _MaxDataRate.value

	def getFilterType(self):
		_FilterType = ctypes.c_int()

		__func = PhidgetSupport.getDll().PhidgetFrequencyCounter_getFilterType
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_FilterType))

		if result > 0:
			raise PhidgetException(result)

		return _FilterType.value

	def setFilterType(self, FilterType):
		_FilterType = ctypes.c_int(FilterType)

		__func = PhidgetSupport.getDll().PhidgetFrequencyCounter_setFilterType
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _FilterType)

		if result > 0:
			raise PhidgetException(result)


	def getFrequency(self):
		_Frequency = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetFrequencyCounter_getFrequency
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_Frequency))

		if result > 0:
			raise PhidgetException(result)

		return _Frequency.value

	def getMaxFrequency(self):
		_MaxFrequency = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetFrequencyCounter_getMaxFrequency
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxFrequency))

		if result > 0:
			raise PhidgetException(result)

		return _MaxFrequency.value

	def getFrequencyCutoff(self):
		_FrequencyCutoff = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetFrequencyCounter_getFrequencyCutoff
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_FrequencyCutoff))

		if result > 0:
			raise PhidgetException(result)

		return _FrequencyCutoff.value

	def setFrequencyCutoff(self, FrequencyCutoff):
		_FrequencyCutoff = ctypes.c_double(FrequencyCutoff)

		__func = PhidgetSupport.getDll().PhidgetFrequencyCounter_setFrequencyCutoff
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _FrequencyCutoff)

		if result > 0:
			raise PhidgetException(result)


	def getMinFrequencyCutoff(self):
		_MinFrequencyCutoff = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetFrequencyCounter_getMinFrequencyCutoff
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MinFrequencyCutoff))

		if result > 0:
			raise PhidgetException(result)

		return _MinFrequencyCutoff.value

	def getMaxFrequencyCutoff(self):
		_MaxFrequencyCutoff = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetFrequencyCounter_getMaxFrequencyCutoff
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_MaxFrequencyCutoff))

		if result > 0:
			raise PhidgetException(result)

		return _MaxFrequencyCutoff.value

	def getInputMode(self):
		_InputMode = ctypes.c_int()

		__func = PhidgetSupport.getDll().PhidgetFrequencyCounter_getInputMode
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_InputMode))

		if result > 0:
			raise PhidgetException(result)

		return _InputMode.value

	def setInputMode(self, InputMode):
		_InputMode = ctypes.c_int(InputMode)

		__func = PhidgetSupport.getDll().PhidgetFrequencyCounter_setInputMode
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _InputMode)

		if result > 0:
			raise PhidgetException(result)


	def getPowerSupply(self):
		_PowerSupply = ctypes.c_int()

		__func = PhidgetSupport.getDll().PhidgetFrequencyCounter_getPowerSupply
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_PowerSupply))

		if result > 0:
			raise PhidgetException(result)

		return _PowerSupply.value

	def setPowerSupply(self, PowerSupply):
		_PowerSupply = ctypes.c_int(PowerSupply)

		__func = PhidgetSupport.getDll().PhidgetFrequencyCounter_setPowerSupply
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _PowerSupply)

		if result > 0:
			raise PhidgetException(result)


	def reset(self):
		__func = PhidgetSupport.getDll().PhidgetFrequencyCounter_reset
		__func.restype = ctypes.c_int32
		result = __func(self.handle)

		if result > 0:
			raise PhidgetException(result)


	def getTimeElapsed(self):
		_TimeElapsed = ctypes.c_double()

		__func = PhidgetSupport.getDll().PhidgetFrequencyCounter_getTimeElapsed
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_TimeElapsed))

		if result > 0:
			raise PhidgetException(result)

		return _TimeElapsed.value



import sys
import ctypes
class RTDWireSetup:
	# Configures the device to make resistance calculations based on a 2-wire RTD setup.
	RTD_WIRE_SETUP_2WIRE = 1
	# Configures the device to make resistance calculations based on a 3-wire RTD setup.
	RTD_WIRE_SETUP_3WIRE = 2
	# Configures the device to make resistance calculations based on a 4-wire RTD setup.
	RTD_WIRE_SETUP_4WIRE = 3

	@classmethod
	def getName(self, val):
		if val == self.RTD_WIRE_SETUP_2WIRE:
			return "RTD_WIRE_SETUP_2WIRE"
		if val == self.RTD_WIRE_SETUP_3WIRE:
			return "RTD_WIRE_SETUP_3WIRE"
		if val == self.RTD_WIRE_SETUP_4WIRE:
			return "RTD_WIRE_SETUP_4WIRE"
		return "<invalid enumeration value>"



import sys
import ctypes


class GPSTime(ctypes.Structure):
	_fields_ = [
		("_tm_ms", ctypes.c_int16),
		("_tm_sec", ctypes.c_int16),
		("_tm_min", ctypes.c_int16),
		("_tm_hour", ctypes.c_int16),
	]

	def __init__(self):
		self.tm_ms = 0
		self.tm_sec = 0
		self.tm_min = 0
		self.tm_hour = 0

	def fromPython(self):
		self._tm_ms = self.tm_ms
		self._tm_sec = self.tm_sec
		self._tm_min = self.tm_min
		self._tm_hour = self.tm_hour
		return self

	def toPython(self):
		if self._tm_ms == None:
			self.tm_ms = None
		else:
			self.tm_ms = self._tm_ms
		if self._tm_sec == None:
			self.tm_sec = None
		else:
			self.tm_sec = self._tm_sec
		if self._tm_min == None:
			self.tm_min = None
		else:
			self.tm_min = self._tm_min
		if self._tm_hour == None:
			self.tm_hour = None
		else:
			self.tm_hour = self._tm_hour
		return self

	def __str__(self):
		return ("[GPSTime] ("
			"tm_ms: " + str(self.tm_ms) + ", "
			"tm_sec: " + str(self.tm_sec) + ", "
			"tm_min: " + str(self.tm_min) + ", "
			"tm_hour: " + str(self.tm_hour) + 
			")")



import sys
import ctypes
class SpatialPrecision:
	# High precision sensor is used when possible, fallback to low precision sensor.
	SPATIAL_PRECISION_HYBRID = 0
	# High precision sensor is always used.
	SPATIAL_PRECISION_HIGH = 1
	# Low precision sensor is always used.
	SPATIAL_PRECISION_LOW = 2

	@classmethod
	def getName(self, val):
		if val == self.SPATIAL_PRECISION_HYBRID:
			return "SPATIAL_PRECISION_HYBRID"
		if val == self.SPATIAL_PRECISION_HIGH:
			return "SPATIAL_PRECISION_HIGH"
		if val == self.SPATIAL_PRECISION_LOW:
			return "SPATIAL_PRECISION_LOW"
		return "<invalid enumeration value>"



import sys
import ctypes
class MotorDriveType:
	# Configures the motor to coast
	MOTOR_DRIVE_TYPE_COAST = 1
	# Configures the motor for active control
	MOTOR_DRIVE_TYPE_ACTIVE = 2

	@classmethod
	def getName(self, val):
		if val == self.MOTOR_DRIVE_TYPE_COAST:
			return "MOTOR_DRIVE_TYPE_COAST"
		if val == self.MOTOR_DRIVE_TYPE_ACTIVE:
			return "MOTOR_DRIVE_TYPE_ACTIVE"
		return "<invalid enumeration value>"



import sys
import ctypes
class DataAdapterIOVoltage:
	# Voltage supplied by external device
	IO_VOLTAGE_EXTERN = 1
	# 1.8V
	IO_VOLTAGE_1_8V = 2
	# 2.5V
	IO_VOLTAGE_2_5V = 3
	# 3.3V
	IO_VOLTAGE_3_3V = 4
	# 5.0V
	IO_VOLTAGE_5_0V = 5

	@classmethod
	def getName(self, val):
		if val == self.IO_VOLTAGE_EXTERN:
			return "IO_VOLTAGE_EXTERN"
		if val == self.IO_VOLTAGE_1_8V:
			return "IO_VOLTAGE_1_8V"
		if val == self.IO_VOLTAGE_2_5V:
			return "IO_VOLTAGE_2_5V"
		if val == self.IO_VOLTAGE_3_3V:
			return "IO_VOLTAGE_3_3V"
		if val == self.IO_VOLTAGE_5_0V:
			return "IO_VOLTAGE_5_0V"
		return "<invalid enumeration value>"



import sys
import ctypes
from Phidget22.PhidgetSupport import PhidgetSupport
from Phidget22.Async import *
from Phidget22.RFIDProtocol import RFIDProtocol
from Phidget22.PhidgetException import PhidgetException

from Phidget22.Phidget import Phidget

class RFID(Phidget):

	def __init__(self):
		Phidget.__init__(self)
		self.handle = ctypes.c_void_p()

		if sys.platform == 'win32':
			self._TagFactory = ctypes.WINFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.c_char_p, ctypes.c_int)
		else:
			self._TagFactory = ctypes.CFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.c_char_p, ctypes.c_int)
		self._Tag = None
		self._onTag = None

		if sys.platform == 'win32':
			self._TagLostFactory = ctypes.WINFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.c_char_p, ctypes.c_int)
		else:
			self._TagLostFactory = ctypes.CFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.c_char_p, ctypes.c_int)
		self._TagLost = None
		self._onTagLost = None

		__func = PhidgetSupport.getDll().PhidgetRFID_create
		__func.restype = ctypes.c_int32
		res = __func(ctypes.byref(self.handle))

		if res > 0:
			raise PhidgetException(res)

	def __del__(self):
		Phidget.__del__(self)

	def _localTagEvent(self, handle, userPtr, Tag, Protocol):
		if self._Tag == None:
			return
		Tag = Tag.decode('utf-8')
		self._Tag(self, Tag, Protocol)

	def setOnTagHandler(self, handler):
		if handler == None:
			self._Tag = None
			self._onTag = None
		else:
			self._Tag = handler
			self._onTag = self._TagFactory(self._localTagEvent)

		try:
			__func = PhidgetSupport.getDll().PhidgetRFID_setOnTagHandler
			__func.restype = ctypes.c_int32
			res = __func(self.handle, self._onTag, None)
		except RuntimeError:
			self._Tag = None
			self._onTag = None

	def _localTagLostEvent(self, handle, userPtr, Tag, Protocol):
		if self._TagLost == None:
			return
		Tag = Tag.decode('utf-8')
		self._TagLost(self, Tag, Protocol)

	def setOnTagLostHandler(self, handler):
		if handler == None:
			self._TagLost = None
			self._onTagLost = None
		else:
			self._TagLost = handler
			self._onTagLost = self._TagLostFactory(self._localTagLostEvent)

		try:
			__func = PhidgetSupport.getDll().PhidgetRFID_setOnTagLostHandler
			__func.restype = ctypes.c_int32
			res = __func(self.handle, self._onTagLost, None)
		except RuntimeError:
			self._TagLost = None
			self._onTagLost = None

	def getAntennaEnabled(self):
		_AntennaEnabled = ctypes.c_int()

		__func = PhidgetSupport.getDll().PhidgetRFID_getAntennaEnabled
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_AntennaEnabled))

		if result > 0:
			raise PhidgetException(result)

		return bool(_AntennaEnabled.value)

	def setAntennaEnabled(self, AntennaEnabled):
		_AntennaEnabled = ctypes.c_int(AntennaEnabled)

		__func = PhidgetSupport.getDll().PhidgetRFID_setAntennaEnabled
		__func.restype = ctypes.c_int32
		result = __func(self.handle, _AntennaEnabled)

		if result > 0:
			raise PhidgetException(result)


	def getLastTag(self):
		_tagString = (ctypes.c_char * 25)()
		_tagStringLen = ctypes.c_int32(25)
		_protocol = ctypes.c_int()

		__func = PhidgetSupport.getDll().PhidgetRFID_getLastTag
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_tagString), _tagStringLen, ctypes.byref(_protocol))

		if result > 0:
			raise PhidgetException(result)

		return _tagString.value.decode('utf-8'), _protocol.value

	def getTagPresent(self):
		_TagPresent = ctypes.c_int()

		__func = PhidgetSupport.getDll().PhidgetRFID_getTagPresent
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_TagPresent))

		if result > 0:
			raise PhidgetException(result)

		return bool(_TagPresent.value)

	def write(self, tagString, protocol, lockTag):
		_tagString = ctypes.create_string_buffer(tagString.encode('utf-8'))
		_protocol = ctypes.c_int(protocol)
		_lockTag = ctypes.c_int(lockTag)

		__func = PhidgetSupport.getDll().PhidgetRFID_write
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_tagString), _protocol, _lockTag)

		if result > 0:
			raise PhidgetException(result)




import sys
import ctypes
from Phidget22.PhidgetSupport import PhidgetSupport
from Phidget22.Async import *
from Phidget22.PhidgetException import PhidgetException

from Phidget22.Phidget import Phidget

class Dictionary(Phidget):

	def __init__(self):
		Phidget.__init__(self)
		self.handle = ctypes.c_void_p()

		if sys.platform == 'win32':
			self._AddFactory = ctypes.WINFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.c_char_p, ctypes.c_char_p)
		else:
			self._AddFactory = ctypes.CFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.c_char_p, ctypes.c_char_p)
		self._Add = None
		self._onAdd = None

		if sys.platform == 'win32':
			self._RemoveFactory = ctypes.WINFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.c_char_p)
		else:
			self._RemoveFactory = ctypes.CFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.c_char_p)
		self._Remove = None
		self._onRemove = None

		if sys.platform == 'win32':
			self._UpdateFactory = ctypes.WINFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.c_char_p, ctypes.c_char_p)
		else:
			self._UpdateFactory = ctypes.CFUNCTYPE(None, ctypes.c_void_p, ctypes.c_void_p, ctypes.c_char_p, ctypes.c_char_p)
		self._Update = None
		self._onUpdate = None

		__func = PhidgetSupport.getDll().PhidgetDictionary_create
		__func.restype = ctypes.c_int32
		res = __func(ctypes.byref(self.handle))

		if res > 0:
			raise PhidgetException(res)

	def __del__(self):
		Phidget.__del__(self)

	def _localAddEvent(self, handle, userPtr, key, value):
		if self._Add == None:
			return
		key = key.decode('utf-8')
		value = value.decode('utf-8')
		self._Add(self, key, value)

	def setOnAddHandler(self, handler):
		if handler == None:
			self._Add = None
			self._onAdd = None
		else:
			self._Add = handler
			self._onAdd = self._AddFactory(self._localAddEvent)

		try:
			__func = PhidgetSupport.getDll().PhidgetDictionary_setOnAddHandler
			__func.restype = ctypes.c_int32
			res = __func(self.handle, self._onAdd, None)
		except RuntimeError:
			self._Add = None
			self._onAdd = None

	def _localRemoveEvent(self, handle, userPtr, key):
		if self._Remove == None:
			return
		key = key.decode('utf-8')
		self._Remove(self, key)

	def setOnRemoveHandler(self, handler):
		if handler == None:
			self._Remove = None
			self._onRemove = None
		else:
			self._Remove = handler
			self._onRemove = self._RemoveFactory(self._localRemoveEvent)

		try:
			__func = PhidgetSupport.getDll().PhidgetDictionary_setOnRemoveHandler
			__func.restype = ctypes.c_int32
			res = __func(self.handle, self._onRemove, None)
		except RuntimeError:
			self._Remove = None
			self._onRemove = None

	def _localUpdateEvent(self, handle, userPtr, key, value):
		if self._Update == None:
			return
		key = key.decode('utf-8')
		value = value.decode('utf-8')
		self._Update(self, key, value)

	def setOnUpdateHandler(self, handler):
		if handler == None:
			self._Update = None
			self._onUpdate = None
		else:
			self._Update = handler
			self._onUpdate = self._UpdateFactory(self._localUpdateEvent)

		try:
			__func = PhidgetSupport.getDll().PhidgetDictionary_setOnUpdateHandler
			__func.restype = ctypes.c_int32
			res = __func(self.handle, self._onUpdate, None)
		except RuntimeError:
			self._Update = None
			self._onUpdate = None

	def add(self, key, value):
		_key = ctypes.create_string_buffer(key.encode('utf-8'))
		_value = ctypes.create_string_buffer(value.encode('utf-8'))

		__func = PhidgetSupport.getDll().PhidgetDictionary_add
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_key), ctypes.byref(_value))

		if result > 0:
			raise PhidgetException(result)


	def removeAll(self):
		__func = PhidgetSupport.getDll().PhidgetDictionary_removeAll
		__func.restype = ctypes.c_int32
		result = __func(self.handle)

		if result > 0:
			raise PhidgetException(result)


	def get(self, key):
		_key = ctypes.create_string_buffer(key.encode('utf-8'))
		_value = (ctypes.c_char * 65536)()
		_valueLen = ctypes.c_int32(65536)

		__func = PhidgetSupport.getDll().PhidgetDictionary_get
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_key), ctypes.byref(_value), _valueLen)

		if result > 0:
			raise PhidgetException(result)

		return _value.value.decode('utf-8')

	def remove(self, key):
		_key = ctypes.create_string_buffer(key.encode('utf-8'))

		__func = PhidgetSupport.getDll().PhidgetDictionary_remove
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_key))

		if result > 0:
			raise PhidgetException(result)


	def scan(self, start):
		_start = ctypes.create_string_buffer(start.encode('utf-8'))
		_keyList = (ctypes.c_char * 65536)()
		_keyListLen = ctypes.c_int32(65536)

		__func = PhidgetSupport.getDll().PhidgetDictionary_scan
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_start), ctypes.byref(_keyList), _keyListLen)

		if result > 0:
			raise PhidgetException(result)

		return _keyList.value.decode('utf-8')

	def set(self, key, value):
		_key = ctypes.create_string_buffer(key.encode('utf-8'))
		_value = ctypes.create_string_buffer(value.encode('utf-8'))

		__func = PhidgetSupport.getDll().PhidgetDictionary_set
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_key), ctypes.byref(_value))

		if result > 0:
			raise PhidgetException(result)


	def update(self, key, value):
		_key = ctypes.create_string_buffer(key.encode('utf-8'))
		_value = ctypes.create_string_buffer(value.encode('utf-8'))

		__func = PhidgetSupport.getDll().PhidgetDictionary_update
		__func.restype = ctypes.c_int32
		result = __func(self.handle, ctypes.byref(_key), ctypes.byref(_value))

		if result > 0:
			raise PhidgetException(result)




import sys
import ctypes


class SpatialEulerAngles(ctypes.Structure):
	_fields_ = [
		("_pitch", ctypes.c_double),
		("_roll", ctypes.c_double),
		("_heading", ctypes.c_double),
	]

	def __init__(self):
		self.pitch = 0
		self.roll = 0
		self.heading = 0

	def fromPython(self):
		self._pitch = self.pitch
		self._roll = self.roll
		self._heading = self.heading
		return self

	def toPython(self):
		if self._pitch == None:
			self.pitch = None
		else:
			self.pitch = self._pitch
		if self._roll == None:
			self.roll = None
		else:
			self.roll = self._roll
		if self._heading == None:
			self.heading = None
		else:
			self.heading = self._heading
		return self

	def __str__(self):
		return ("[SpatialEulerAngles] ("
			"pitch: " + str(self.pitch) + ", "
			"roll: " + str(self.roll) + ", "
			"heading: " + str(self.heading) + 
			")")



import sys
import ctypes
class VoltageSensorType:
	# Default. Configures the channel to be a generic voltage sensor. Unit is volts.
	SENSOR_TYPE_VOLTAGE = 0
	# 1114 - Temperature Sensor
	SENSOR_TYPE_1114 = 11140
	# 1117 - Voltage Sensor
	SENSOR_TYPE_1117 = 11170
	# 1123 - Precision Voltage Sensor
	SENSOR_TYPE_1123 = 11230
	# 1127 - Precision Light Sensor
	SENSOR_TYPE_1127 = 11270
	# 1130 - pH Adapter
	SENSOR_TYPE_1130_PH = 11301
	# 1130 - ORP Adapter
	SENSOR_TYPE_1130_ORP = 11302
	# 1132 - 4-20mA Adapter
	SENSOR_TYPE_1132 = 11320
	# 1133 - Sound Sensor
	SENSOR_TYPE_1133 = 11330
	# 1135 - Precision Voltage Sensor
	SENSOR_TYPE_1135 = 11350
	# 1142 - Light Sensor 1000 lux
	SENSOR_TYPE_1142 = 11420
	# 1143 - Light Sensor 70000 lux
	SENSOR_TYPE_1143 = 11430
	# 3500 - AC Current Sensor 10Amp
	SENSOR_TYPE_3500 = 35000
	# 3501 - AC Current Sensor 25Amp
	SENSOR_TYPE_3501 = 35010
	# 3502 - AC Current Sensor 50Amp
	SENSOR_TYPE_3502 = 35020
	# 3503 - AC Current Sensor 100Amp
	SENSOR_TYPE_3503 = 35030
	# 3507 - AC Voltage Sensor 0-250V (50Hz)
	SENSOR_TYPE_3507 = 35070
	# 3508 - AC Voltage Sensor 0-250V (60Hz)
	SENSOR_TYPE_3508 = 35080
	# 3509 - DC Voltage Sensor 0-200V
	SENSOR_TYPE_3509 = 35090
	# 3510 - DC Voltage Sensor 0-75V
	SENSOR_TYPE_3510 = 35100
	# 3511 - DC Current Sensor 0-10mA
	SENSOR_TYPE_3511 = 35110
	# 3512 - DC Current Sensor 0-100mA
	SENSOR_TYPE_3512 = 35120
	# 3513 - DC Current Sensor 0-1A
	SENSOR_TYPE_3513 = 35130
	# 3514 - AC Active Power Sensor 0-250V*0-30A (50Hz)
	SENSOR_TYPE_3514 = 35140
	# 3515 - AC Active Power Sensor 0-250V*0-30A (60Hz)
	SENSOR_TYPE_3515 = 35150
	# 3516 - AC Active Power Sensor 0-250V*0-5A (50Hz)
	SENSOR_TYPE_3516 = 35160
	# 3517 - AC Active Power Sensor 0-250V*0-5A (60Hz)
	SENSOR_TYPE_3517 = 35170
	# 3518 - AC Active Power Sensor 0-110V*0-5A (60Hz)
	SENSOR_TYPE_3518 = 35180
	# 3519 - AC Active Power Sensor 0-110V*0-15A (60Hz)
	SENSOR_TYPE_3519 = 35190
	# 3584 - 0-50A DC Current Transducer
	SENSOR_TYPE_3584 = 35840
	# 3585 - 0-100A DC Current Transducer
	SENSOR_TYPE_3585 = 35850
	# 3586 - 0-250A DC Current Transducer
	SENSOR_TYPE_3586 = 35860
	# 3587 - +-50A DC Current Transducer
	SENSOR_TYPE_3587 = 35870
	# 3588 - +-100A DC Current Transducer
	SENSOR_TYPE_3588 = 35880
	# 3589 - +-250A DC Current Transducer
	SENSOR_TYPE_3589 = 35890
	# MOT2002 - Motion Sensor Low Sensitivity
	SENSOR_TYPE_MOT2002_LOW = 20020
	# MOT2002 - Motion Sensor Medium Sensitivity
	SENSOR_TYPE_MOT2002_MED = 20021
	# MOT2002 - Motion Sensor High Sensitivity
	SENSOR_TYPE_MOT2002_HIGH = 20022
	# VCP4114 - +-25A DC Current Transducer
	SENSOR_TYPE_VCP4114 = 41140

	@classmethod
	def getName(self, val):
		if val == self.SENSOR_TYPE_VOLTAGE:
			return "SENSOR_TYPE_VOLTAGE"
		if val == self.SENSOR_TYPE_1114:
			return "SENSOR_TYPE_1114"
		if val == self.SENSOR_TYPE_1117:
			return "SENSOR_TYPE_1117"
		if val == self.SENSOR_TYPE_1123:
			return "SENSOR_TYPE_1123"
		if val == self.SENSOR_TYPE_1127:
			return "SENSOR_TYPE_1127"
		if val == self.SENSOR_TYPE_1130_PH:
			return "SENSOR_TYPE_1130_PH"
		if val == self.SENSOR_TYPE_1130_ORP:
			return "SENSOR_TYPE_1130_ORP"
		if val == self.SENSOR_TYPE_1132:
			return "SENSOR_TYPE_1132"
		if val == self.SENSOR_TYPE_1133:
			return "SENSOR_TYPE_1133"
		if val == self.SENSOR_TYPE_1135:
			return "SENSOR_TYPE_1135"
		if val == self.SENSOR_TYPE_1142:
			return "SENSOR_TYPE_1142"
		if val == self.SENSOR_TYPE_1143:
			return "SENSOR_TYPE_1143"
		if val == self.SENSOR_TYPE_3500:
			return "SENSOR_TYPE_3500"
		if val == self.SENSOR_TYPE_3501:
			return "SENSOR_TYPE_3501"
		if val == self.SENSOR_TYPE_3502:
			return "SENSOR_TYPE_3502"
		if val == self.SENSOR_TYPE_3503:
			return "SENSOR_TYPE_3503"
		if val == self.SENSOR_TYPE_3507:
			return "SENSOR_TYPE_3507"
		if val == self.SENSOR_TYPE_3508:
			return "SENSOR_TYPE_3508"
		if val == self.SENSOR_TYPE_3509:
			return "SENSOR_TYPE_3509"
		if val == self.SENSOR_TYPE_3510:
			return "SENSOR_TYPE_3510"
		if val == self.SENSOR_TYPE_3511:
			return "SENSOR_TYPE_3511"
		if val == self.SENSOR_TYPE_3512:
			return "SENSOR_TYPE_3512"
		if val == self.SENSOR_TYPE_3513:
			return "SENSOR_TYPE_3513"
		if val == self.SENSOR_TYPE_3514:
			return "SENSOR_TYPE_3514"
		if val == self.SENSOR_TYPE_3515:
			return "SENSOR_TYPE_3515"
		if val == self.SENSOR_TYPE_3516:
			return "SENSOR_TYPE_3516"
		if val == self.SENSOR_TYPE_3517:
			return "SENSOR_TYPE_3517"
		if val == self.SENSOR_TYPE_3518:
			return "SENSOR_TYPE_3518"
		if val == self.SENSOR_TYPE_3519:
			return "SENSOR_TYPE_3519"
		if val == self.SENSOR_TYPE_3584:
			return "SENSOR_TYPE_3584"
		if val == self.SENSOR_TYPE_3585:
			return "SENSOR_TYPE_3585"
		if val == self.SENSOR_TYPE_3586:
			return "SENSOR_TYPE_3586"
		if val == self.SENSOR_TYPE_3587:
			return "SENSOR_TYPE_3587"
		if val == self.SENSOR_TYPE_3588:
			return "SENSOR_TYPE_3588"
		if val == self.SENSOR_TYPE_3589:
			return "SENSOR_TYPE_3589"
		if val == self.SENSOR_TYPE_MOT2002_LOW:
			return "SENSOR_TYPE_MOT2002_LOW"
		if val == self.SENSOR_TYPE_MOT2002_MED:
			return "SENSOR_TYPE_MOT2002_MED"
		if val == self.SENSOR_TYPE_MOT2002_HIGH:
			return "SENSOR_TYPE_MOT2002_HIGH"
		if val == self.SENSOR_TYPE_VCP4114:
			return "SENSOR_TYPE_VCP4114"
		return "<invalid enumeration value>"



import sys
import ctypes
class DataAdapterProtocol:
	# Basic half-duplex RS485. Always receiving until you send data.
	PROTOCOL_RS485 = 1
	# Uses full-duplex RS422 communication.
	PROTOCOL_RS422 = 2
	# Allows communication with DMX512-compatible devices, such as stage lighting
	PROTOCOL_DMX512 = 3
	# Allows communication with MODBUS RTU compatible devices
	PROTOCOL_MODBUS_RTU = 4
	# Allows communication with SPI compatible devices
	PROTOCOL_SPI = 5
	# Allows communication with I2C compatible devices
	PROTOCOL_I2C = 6
	# Allows communication with UART compatible devices
	PROTOCOL_UART = 7
	# Allows communication with RS232 compatible devices
	PROTOCOL_RS232 = 8

	@classmethod
	def getName(self, val):
		if val == self.PROTOCOL_RS485:
			return "PROTOCOL_RS485"
		if val == self.PROTOCOL_RS422:
			return "PROTOCOL_RS422"
		if val == self.PROTOCOL_DMX512:
			return "PROTOCOL_DMX512"
		if val == self.PROTOCOL_MODBUS_RTU:
			return "PROTOCOL_MODBUS_RTU"
		if val == self.PROTOCOL_SPI:
			return "PROTOCOL_SPI"
		if val == self.PROTOCOL_I2C:
			return "PROTOCOL_I2C"
		if val == self.PROTOCOL_UART:
			return "PROTOCOL_UART"
		if val == self.PROTOCOL_RS232:
			return "PROTOCOL_RS232"
		return "<invalid enumeration value>"
